=======
Credits
=======

Development Lead
----------------

* Gunnar Voet <gvoet@ucsd.edu>

Contributors
------------

None yet. Why not be the first?

Other
-----

This package makes generous use of the (more than awesome) xarray_ package. Try it out if you haven't done so yet!

.. _xarray: http://xarray.pydata.org/

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage